/*--------------------------------------------------------------------
 * FICHERO:  Estilo.c
 * OBJETIVO: Definir las funciones del objeto Estilo
 * AUTOR:    Pedro Reina
 * FECHA:    V.10.2.1995
 *------------------------------------------------------------------*/

/*--------------------------------------------------------------------
 * Ficheros de cabecera
 *------------------------------------------------------------------*/

#include "Estilo.h"

/*--------------------------------------------------------------------
 * Definicin de funciones
 *------------------------------------------------------------------*/

/*--------------------------------------------------------------------
 * FUNCION:  Est_Crea()
 * OBJETIVO: Crear un objeto estilo y darle valores iniciales
 * ENTRADAS: Ninguna
 * SALIDAS:  Una estilo o NIL si no hay memoria para crearlo
 *------------------------------------------------------------------*/
estilo Est_Crea()
  {
  estilo Respuesta;

  Respuesta = (estilo) Mem_Crea(sizeof(Est_st));
  if ( Respuesta )
    {
    Mem_Asigna (Respuesta,0,sizeof(Est_st));   /* Puesta a cero de todo */
    }

  return ( Respuesta );
  }

/*--------------------------------------------------------------------
 * FUNCION:  Est_Destruye()
 * OBJETIVO: Destruir un objeto estilo y liberar la memoria ocupada
 * ENTRADAS: El estilo
 * SALIDAS:  Ninguna
 *------------------------------------------------------------------*/
void Est_Destruye (Estilo)
estilo Estilo;
  {
  if ( Est_Nombre(Estilo) )  { Cad_Destruye (Est_Nombre(Estilo)); }
  if ( Est_Fuente(Estilo) )  { Cad_Destruye (Est_Fuente(Estilo)); }
  Mem_Destruye (Estilo);
  }

/*--------------------------------------------------------------------
 * FUNCION:  Est_Duplica()
 * OBJETIVO: Duplicar un estilo
 * ENTRADAS: Un estilo
 * SALIDAS:  Una copia del estilo o NIL si no se puede crear
 *------------------------------------------------------------------*/
estilo Est_Duplica (Estilo)
estilo Estilo;
  {
  estilo Nuevo;

  if ( Nuevo = Est_Crea() )
    {
    Est_PonNumero (Nuevo, Est_Numero(Estilo));
    Est_PonNombre (Nuevo, Est_Nombre(Estilo));
    Est_PonTipoFuente (Nuevo, Est_TipoFuente(Estilo));
    Est_PonNumeroFuente (Nuevo, Est_NumeroFuente(Estilo));
    Est_PonFuente (Nuevo, Est_Fuente(Estilo));
    Est_PonTamano (Nuevo, Est_Tamano(Estilo));
    Est_PonJustificacion (Nuevo, Est_Justificacion(Estilo));
    Est_PonMargenIzquierdo (Nuevo, Est_MargenIzquierdo(Estilo));
    Est_PonMargenDerecho (Nuevo, Est_MargenDerecho(Estilo));
    Est_PonMargenSangrado (Nuevo, Est_MargenSangrado(Estilo));
    }

  return ( Nuevo );
  }

/*--------------------------------------------------------------------
 * FUNCION:  Est_PonNombre()
 * OBJETIVO: Poner el nombre a un estilo
 * ENTRADAS: El estilo y la cadena del nombre
 * SALIDAS:  La cadena del nombre
 * EJEMPLO:  Est_PonNombre ( Estilo, NombreEstilo )
 *------------------------------------------------------------------*/
cadena Est_PonNombre (Estilo,Nombre)
estilo Estilo;
cadena Nombre;
  {
  if ( Est_Nombre(Estilo) )  { Cad_Destruye (Est_Nombre(Estilo)); }
  Estilo->Nombre = Cad_Duplica (Nombre);

  return ( Nombre );
  }

/*--------------------------------------------------------------------
 * FUNCION:  Est_PonFuente()
 * OBJETIVO: Poner la fuente a un estilo
 * ENTRADAS: El estilo y la cadena de la fuente
 * SALIDAS:  La cadena del fuente
 * EJEMPLO:  Est_PonFuente ( Estilo, NombreFuente )
 *------------------------------------------------------------------*/
cadena Est_PonFuente (Estilo,Fuente)
estilo Estilo;
cadena Fuente;
  {
  if ( Est_Fuente(Estilo) )  { Cad_Destruye (Est_Fuente(Estilo)); }
  Estilo->Fuente = Cad_Duplica (Fuente);

  return ( Fuente );
  }
